# stompy: spatial tools for ocean modeling in python

Various python modules related to modeling and oceanographic data analysis.

## Prerequisites

 `stompy` requires a Python 3 environment with `gdal` installed. There are many ways to set this up. The recommended method would be creating a `mamba` (or `conda`) environment:

 ```
mamba create -n <env-name> python gdal
mamba activate <env-name>
```

## Installation


### Installing with `pip`

```
pip install stompy-ocean
```

### Installing with `mamba`/`conda`

Coming soon

## Documentation

See the [Documentation pages](https://stompy.readthedocs.io/en/latest/) for descriptions of the various modules.

## Issues

If you run into any bugs using `stompy`, you are encouraged to submit an [Issue](https://github.com/rustychris/stompy/issues) or PR to this repo.
